@@ -23,3 +23,6 @@ LOGGING = {
 ANSIBLE_API_HOSTNAME = "https://" + socket.getfqdn()
 ANSIBLE_CONTENT_HOSTNAME = settings.CONTENT_ORIGIN + "/pulp/content"
 ANSIBLE_SIGNING_TASK_LIMITER = 10
+ANSIBLE_CERTS_DIR = "/etc/pulp/certs/"
+ANSIBLE_DEFAULT_DISTRIBUTION_PATH = None
+ANSIBLE_URL_NAMESPACE = ""
