@@ -630,7 +630,7 @@ class CollectionSyncFirstStage(Stage):
                 cv_signature = CollectionVersionSignature(
                     signed_collection=collection_version,
                     data=sig,
-                    digest=hashlib.sha256(sig),
+                    digest=hashlib.sha256(sig).hexdigest(),
                     pubkey_fingerprint=signature["pubkey_fingerprint"],
                 )
                 await self.put(DeclarativeContent(content=cv_signature))
@@ -798,6 +798,7 @@ class CollectionSyncFirstStage(Stage):
 
             if not isinstance(col_results, FileNotFoundError):
                 collection_metadata_list = parse_metadata(col_results)
+
                 self._unpaginated_collection_metadata = defaultdict(dict)
                 for collection in collection_metadata_list:
                     namespace = collection["namespace"]
